@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1995-2023 Free Software Foundation, Inc.
+  Copyright (C) 1995-2025 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -70,6 +70,7 @@
 #include <error.h>
 #include <errno.h>
 #include <fcntl.h>
+#include <float.h>
 #include <netdb.h>
 #include <pwd.h>
 #include <signal.h>
@@ -87,22 +88,14 @@
 # include <idna.h>
 #endif
 
+#include <intprops.h>
+#include <timespec.h>
+
 #include "ftp_var.h"
 #include "attribute.h"
 
 #ifdef __CYGWIN__
 #include <io.h>
-typedef _sig_func_ptr sig_t;
-#endif
-
-#if !HAVE_DECL_FCLOSE
-/* Some systems don't declare fclose in <stdio.h>, so do it ourselves.  */
-extern int fclose (FILE *);
-#endif
-
-#if !HAVE_DECL_PCLOSE
-/* Some systems don't declare pclose in <stdio.h>, so do it ourselves.  */
-extern int pclose (FILE *);
 #endif
 
 int data = -1;
@@ -119,7 +112,7 @@ socklen_t ctladdrlen;		/* Applies to all addresses.  */
 
 /* For temporary resolving: hookup() and initconn()/noport.  */
 static char ia[INET6_ADDRSTRLEN];
-static char portstr[10];
+static char portstr[INT_STRLEN_BOUND (in_port_t) + 1];
 
 FILE *cin, *cout;
 
@@ -128,7 +121,7 @@ FILE *cin, *cout;
 #endif
 
 char *
-hookup (char *host, int port)
+hookup (char *host, in_port_t port)
 {
   struct addrinfo hints, *ai = NULL, *res = NULL;
   struct timeval timeout;
@@ -154,7 +147,8 @@ hookup (char *host, int port)
   rhost = strdup (host);
 #endif
 
-  snprintf (portstr, sizeof (portstr) - 1, "%u", port);
+
+  snprintf (portstr, sizeof portstr, "%u", port);
   memset (&hisctladdr, 0, sizeof (hisctladdr));
   memset (&hints, 0, sizeof (hints));
 
@@ -224,7 +218,7 @@ hookup (char *host, int port)
 			 sizeof (timeout));
 
       ctladdrlen = ai->ai_addrlen;
-      memmove ((caddr_t) & hisctladdr, ai->ai_addr, ai->ai_addrlen);
+      memmove (&hisctladdr, ai->ai_addr, ai->ai_addrlen);
       break;
     }				/* for (ai = ai->ai_next) */
 
@@ -300,9 +294,6 @@ bad:
 int
 login (char *host)
 {
-#if !HAVE_DECL_GETPASS
-  extern char *getpass ();
-#endif
   char tmp[80];
   char *user, *pass, *acct, *p;
   int n, aflag = 0;
@@ -613,7 +604,7 @@ void
 sendrequest (char *cmd, char *local, char *remote, int printnames)
 {
   struct stat st;
-  struct timeval start, stop;
+  struct timespec start, stop;
   int c, d;
   FILE *fin, *dout = 0, *popen (const char *, const char *);
   int (*closefunc) (FILE *);
@@ -793,7 +784,7 @@ sendrequest (char *cmd, char *local, char *remote, int printnames)
       bufsize = blksize;
     }
 
-  gettimeofday (&start, (struct timezone *) 0);
+  start = current_timespec ();
   oldintp = signal (SIGPIPE, SIG_IGN);
   switch (curtype)
     {
@@ -879,7 +870,7 @@ sendrequest (char *cmd, char *local, char *remote, int printnames)
   if (closefunc != NULL)
     (*closefunc) (fin);
   fclose (dout);
-  gettimeofday (&stop, (struct timezone *) 0);
+  stop = current_timespec ();
   getreply (0);
   signal (SIGINT, oldintr);
   if (oldintp)
@@ -907,7 +898,7 @@ abort:
   code = -1;
   if (closefunc != NULL && fin != NULL)
     (*closefunc) (fin);
-  gettimeofday (&stop, (struct timezone *) 0);
+  stop = current_timespec ();
   if (bytes > 0)
     ptransfer ("sent", bytes, &start, &stop);
 }
@@ -937,7 +928,7 @@ recvrequest (char *cmd, char *local, char *remote, char *lmode,
   static int bufsize = 0;
   static char *buf;
   long long bytes = 0, local_hashbytes = hashbytes;
-  struct timeval start, stop;
+  struct timespec start, stop;
 
   is_retr = strcmp (cmd, "RETR") == 0;
   if (is_retr && verbose && printnames)
@@ -1070,7 +1061,7 @@ recvrequest (char *cmd, char *local, char *remote, char *lmode,
       bufsize = blksize;
     }
 
-  gettimeofday (&start, (struct timezone *) 0);
+  start = current_timespec ();
   switch (curtype)
     {
 
@@ -1222,7 +1213,7 @@ recvrequest (char *cmd, char *local, char *remote, char *lmode,
   if (oldintp)
     signal (SIGPIPE, oldintp);
   fclose (din);
-  gettimeofday (&stop, (struct timezone *) 0);
+  stop = current_timespec ();
   getreply (0);
   if (bytes > 0 && is_retr)
     ptransfer ("received", bytes, &start, &stop);
@@ -1252,7 +1243,7 @@ abort:
     (*closefunc) (fout);
   if (din)
     fclose (din);
-  gettimeofday (&stop, (struct timezone *) 0);
+  stop = current_timespec ();
   if (bytes > 0)
     ptransfer ("received", bytes, &start, &stop);
   signal (SIGINT, oldintr);
@@ -1663,53 +1654,34 @@ dataconn (char *lmode)
 }
 
 void
-ptransfer (char *direction, long long int bytes,
-	   struct timeval *t0, struct timeval *t1)
+ptransfer (char *direction, long long int bytes, struct timespec *t0,
+	   struct timespec *t1)
 {
-  struct timeval td;
-  float s, bs;
+  double s, bs;
 
   if (verbose)
     {
-      tvsub (&td, t1, t0);
-      s = td.tv_sec + (td.tv_usec / 1000000.);
-#define nz(x)	((x) == 0 ? 1 : (x))
-      bs = bytes / nz (s);
+      struct timespec ts = timespec_sub (*t1, *t0);
+      double seconds = timespectod (ts);
+      double bytes_per_second;
 
-      printf ("%lld bytes %s in %.3g seconds", bytes, direction, s);
+      /* Don't divide by zero.  Can this happen?  */
+      if (seconds == 0.0)
+	seconds = DBL_MIN;
 
-      if (bs > 1048576.0)
-	printf (" (%.3g Mbytes/s)\n", bs / 1048576.0);
-      else if (bs > 1024.0)
-	printf (" (%.3g kbytes/s)\n", bs / 1024.0);
+      bytes_per_second = bytes / seconds;
+
+      printf ("%lld bytes %s in %.4f seconds", bytes, direction, seconds);
+
+      if (bytes_per_second > 1048576.0)
+	printf (" (%.4f Mbytes/s)\n", bytes_per_second / 1048576.0);
+      else if (bytes_per_second > 1024.0)
+	printf (" (%.4f kbytes/s)\n", bytes_per_second / 1024.0);
       else
-	printf (" (%.3g bytes/s)\n", bs);
+	printf (" (%.4f bytes/s)\n", bytes_per_second);
     }
 }
 
-/*
-void
-tvadd(tsum, t0)
-	struct timeval *tsum, *t0;
-{
-
-	tsum->tv_sec += t0->tv_sec;
-	tsum->tv_usec += t0->tv_usec;
-	if (tsum->tv_usec > 1000000)
-		tsum->tv_sec++, tsum->tv_usec -= 1000000;
-}
-*/
-
-void
-tvsub (struct timeval *tdiff, struct timeval *t1, struct timeval *t0)
-{
-
-  tdiff->tv_sec = t1->tv_sec - t0->tv_sec;
-  tdiff->tv_usec = t1->tv_usec - t0->tv_usec;
-  if (tdiff->tv_usec < 0)
-    tdiff->tv_sec--, tdiff->tv_usec += 1000000;
-}
-
 void
 psabort (int sig MAYBE_UNUSED)
 {
