@@ -1,5 +1,5 @@
 /* logwtmp.c - A version of BSDs `logwtmp' that should be widely portable
-  Copyright (C) 1997-2022 Free Software Foundation, Inc.
+  Copyright (C) 1997-2025 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -44,10 +44,6 @@
 #endif
 #include <string.h>
 
-#if !HAVE_DECL_ERRNO
-extern int errno;
-#endif
-
 #ifndef O_BINARY
 #define O_BINARY 0
 #endif
@@ -58,7 +54,7 @@ _logwtmp (struct utmpx *ut)
 #else /* !HAVE_UTMPX_H */
 static void
 _logwtmp (struct utmp *ut)
-#endif /* !HAVE_UTMP_H */
+#endif				/* !HAVE_UTMP_H */
 {
 #ifdef KEEP_OPEN
   static int fd = -1;
@@ -145,7 +141,7 @@ logwtmp (char *line, char *name, char *host)
       ut.ut_host[sizeof (ut.ut_host) - 1] = '\0';
       ut.ut_syslen = sizeof (ut.ut_host);
     }
-# endif /* UT_SYSLEN */
+# endif/* UT_SYSLEN */
 #endif /* UT_HOST */
 
 #if defined HAVE_STRUCT_UTMP_UT_TV || defined HAVE_STRUCT_UTMPX_UT_TV
