@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 1994-2023 Free Software Foundation, Inc.
+  Copyright (C) 1994-2025 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -211,11 +211,11 @@ static struct argp_option argp_options[] = {
    "resolve IP addresses when setting environment variables "
    "(see --environment)", GRP + 1},
 #ifdef __CYGWIN__
-  {0,0,0,0,"Cygwin-specific options:",GRP+2},
+  {0,0,0,0,"Cygwin-specific options:",GRP + 2},
   {"no-daemonize", 'D', NULL, 0,
-   "Do not run as a daemon", GRP+2},
+   "Do not run as a daemon", GRP + 2},
   {"traditional-daemon", 'T', NULL, 0,
-   "This option is present for backwards compatibility.", GRP+2},
+   "This option is present for backwards compatibility.", GRP + 2},
 #endif /* __CYGWIN__ */
 #undef GRP
   {NULL, 0, NULL, 0, NULL, 0}
@@ -1073,13 +1073,13 @@ getconfigent (FILE *fconfig, const char *file, size_t *line)
   if (serv_node)
     return next_node_sep (sep);
 
-  memset ((caddr_t) sep, 0, sizeof *sep);
+  memset (sep, 0, sizeof *sep);
 
   while (1)
     {
       argcv_free (argc, argv);
       freeconfig (sep);
-      memset ((caddr_t) sep, 0, sizeof *sep);
+      memset (sep, 0, sizeof *sep);
 
       do
 	{
