@@ -1,5 +1,5 @@
 /* syslogd - log system messages
-  Copyright (C) 1997-2023 Free Software Foundation, Inc.
+  Copyright (C) 1997-2025 Free Software Foundation, Inc.
 
   This file is part of GNU Inetutils.
 
@@ -278,7 +278,6 @@ void logerror (const char *);
 void logmsg (int, const char *, const char *, int);
 void printline (const char *, const char *);
 void printsys (const char *);
-char *ttymsg (struct iovec *, int, char *, int);
 void wallmsg (struct filed *, struct iovec *);
 char **crunch_list (char **oldlist, char *list);
 char *textpri (int pri);
@@ -366,7 +365,7 @@ static struct argp_option argp_options[] = {
   {"mark", 'm', "INTVL", 0, "specify timestamp interval in minutes"
    " (0 for no timestamping)", GRP + 1},
   {"no-detach", 'n', NULL, 0, "do not enter daemon mode", GRP + 1},
-  {"no-daemonize", 'D', NULL, 0, "Synonym for -n", GRP+1},
+  {"no-daemonize", 'D', NULL, 0, "Synonym for -n", GRP + 1},
   {"no-forward", OPT_NO_FORWARD, NULL, 0, "do not forward any messages "
    "(overrides --hop)", GRP + 1},
 #ifdef PATH_KLOG
@@ -1660,7 +1659,7 @@ wallmsg (struct filed *f, struct iovec *iov)
 	  /* Note we're using our own version of ttymsg
 	     which does a double fork () to not have
 	     zombies.  No need to waitpid().  */
-	  p = ttymsg (iov, IOVCNT, line, TTYMSGTIME);
+	  p = inetutils_ttymsg (iov, IOVCNT, line, TTYMSGTIME);
 	  if (p != NULL)
 	    {
 	      errno = 0;	/* Already in message. */
@@ -1673,7 +1672,7 @@ wallmsg (struct filed *f, struct iovec *iov)
 	if (!strncmp (f->f_un.f_user.f_unames[i], UT_USER (utp),
 		      sizeof (UT_USER (utp))))
 	  {
-	    p = ttymsg (iov, IOVCNT, line, TTYMSGTIME);
+	    p = inetutils_ttymsg (iov, IOVCNT, line, TTYMSGTIME);
 	    if (p != NULL)
 	      {
 		errno = 0;	/* Already in message. */
